function [phis,mu,energy] = groundstate2dsys(h,c,N,theta,NH,beta,exact,potential,m,omega)
%
% Calling 
%
% [psis,mu,energy] = groundstate2d3(theta,NH)
%
% the harmonic potential (x^2+gammay*y^2)/2 is used.
%
% Calling
%
% [psis,mu,energy] = groundstate2d3(theta,NH,gammay,@v,a,b,...)
%
% the potential defined in the function v(x,a,b,...) is used. 
% a,b,... are optional parameters for the potential v(x).
%
tol = 1e-7;
d = h*c./m;
[phis,Hw,ev,diffpotential,contparams] = init2dsys(N,NH,h,d,c,beta,potential,m,omega);
l = length(potential);
phisold = phis;
convergence = 0;
% Newton
counter(1) = 1;
%continuation technique
params{1} = ones(l,1);
params{2} = theta;
contparams{2} = zeros(l);
for i = 1:l
  for j = 1:l
    contparams{2}(i,j) = min(theta(i,j),1/sqrt(N(i)*N(j)));
  end
end  
contparamsold = contparams;
contparamsinc{1} = 0.25*ones(l,1);
contparamsinc{2} = 0.25*ones(l);
contparamsincmin{1} = 1e-6*ones(l,1);
contparamsincmin{2} = 1e-6*ones(l);
conttolerance = tol*1e5; % magic number
maxnewtoniter = 50; % magic number
optnewtoniter = 2;
singtol = []; % magic number used in newton2d
alphainit = 1e-2; % magic number
lambdamin = 1e-5; % magic number  % to be removed afterwards
%while (min(contparams >= params) == 0)
while ((max(contparams{1} ~= params{1})) | (max(max(contparams{2} ~= params{2}))))
  contparams{1} = min(params{1},contparamsold{1}.*(1+contparamsinc{1}));
  contparams{2} = min(params{2},contparamsold{2}.*(1+contparamsinc{2}));
  phis = phisold;
  % perform one continuation cycle
  [retcode,errest,phis,newtoniter] = minimizesys(phis,contparams,alphainit,...
    Hw,ev,diffpotential,@energy2dsys,@phirw2dsys,@residual2dsys,@newton2dsys,@error2dsys,...
    0,singtol,conttolerance,maxnewtoniter,N,NH);
  if (retcode == 1 | errest > conttolerance)
    % newton did not converge
    contparamsinc{1} = contparamsinc{1}/2;		
    contparamsinc{2} = contparamsinc{2}/2;		
    warning('Decreasing continuation increments.');
    if (max(contparamsinc{1} < contparamsincmin{1}) | max(max((contparamsinc{2} < contparamsincmin{2})))) 
      error('Minimum value for the parameter increments reached.')
    end
  else
    % newton converged
    if (newtoniter < optnewtoniter)
       % if newton converged within 2 steps increase increment
       contparamsinc{1} = 2*contparamsinc{1};
       contparamsinc{2} = 2*contparamsinc{2};
    end
    % the new theta is temptheta
    contparamsold = contparams;		
    phisold = phis;
    counter(1) = counter(1)+1;
  end
end
counter(1)
contparams = params;
% now temptheta == theta and tempcoef == 1
errest = tol+1;
alphainit = alphainit/100;
optalpha = alphainit;
counter(2) = 0;
maxnewtoniter = 500;
[retcode,errest,phis,newtoniter,energy,mu] = minimizesys(phis,contparams,alphainit,Hw,ev,diffpotential,...
  @energy2dsys,@phirw2dsys,@residual2dsys,@newton2dsys,@error2dsys,2,singtol,tol,maxnewtoniter,N,NH);
energy = h*energy;
mu = h*mu;
counter(2) = newtoniter;
counter(2)
if (retcode == 1)
% not possible to find an acceptable steplength -> stop the
% iteration
  warning(sprintf('Not possible to further reduce the energy. Current errest: %e',errest));
end
for i = 1:l
  phis{i} = sqrt(c)*reshape(phis{i},NH(2),NH(1));
end
phis(l+1) = [];
